# ApplicantsSituationEnum


## Enum

* `SINGLE` (value: `'SINGLE'`)

* `COUPLE` (value: `'COUPLE'`)

* `ROOMATES` (value: `'ROOMATES'`)

* `SOLID_ROOMATES` (value: `'SOLID_ROOMATES'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


